@@ -24,13 +24,19 @@ if openai_org is not None:
 
 @dataclasses.dataclass
 class OpenAIDecodingArguments(object):
+    suffix: Optional[str] = None
     max_tokens: int = 1800
     temperature: float = 0.2
     top_p: float = 1.
     n: int = 1
-    stop: Optional[Tuple[str, ...]] = None
+    stream: bool = False
     logprobs: Optional[int] = None
     echo: bool = False
+    stop: Optional[Tuple[str, ...]] = None
+    presence_penalty: float = 0.0
+    frequency_penalty: float = 0.0
+    best_of: int = 1
+    logit_bias: Optional[dict] = None
     # Heuristic stop when about to generate next function.
     # stop: Optional[Tuple[str, ...]] = ("}\n\nstatic", "}\n\n/*")
 
@@ -44,6 +50,13 @@ def _openai_completion(
     max_batches=sys.maxsize,  # This is useful during testing.
     return_text=False,  # Return text instead of full completion object (which contains things like logprob).
 ):
+    """Decode with OpenAI API.
+
+    If prompts is a string, returns a single completion object (which may contain things like logprob).
+    If prompts is a sequence, returns a list of completions objects.
+    If return_text is True, the completion objects are all strings.
+    If decoding_args.n > 1, returns a nested list, where each entry is a list of completion objects for the same prompt.
+    """
     is_single_prompt = isinstance(prompts, str)
     if is_single_prompt:
         prompts = [prompts]
@@ -67,13 +80,7 @@ def _openai_completion(
                 completion_batch = openai.Completion.create(
                     model=model_name,
                     prompt=prompt_batch,
-                    max_tokens=decoding_args.max_tokens,
-                    temperature=decoding_args.temperature,
-                    top_p=decoding_args.top_p,
-                    n=decoding_args.n,
-                    stop=decoding_args.stop,
-                    logprobs=decoding_args.logprobs,
-                    echo=decoding_args.echo,
+                    **decoding_args.__dict__,
                 )
                 completions.extend(completion_batch.choices)
                 break
@@ -84,7 +91,12 @@ def _openai_completion(
 
     if return_text:
         completions = [completion.text for completion in completions]
-    if is_single_prompt and decoding_args.n == 1:
+    if decoding_args.n > 1:
+        # make completions a nested list, where each entry is a consecutive decoding_args.n of original entries.
+        completions = [
+            completions[i: i + decoding_args.n] for i in range(0, len(completions), decoding_args.n)
+        ]
+    if is_single_prompt:
         completions, = completions  # Return non-tuple if only 1 input and 1 generation.
     return completions
 
